pub struct LineMap { /* private fields */ }Expand description
Maps visual line numbers to AST nodes
Implementations
Sourceimpl LineMap
impl LineMap
pub fn new() -> Self
Sourcepub fn from_markdown(markdown: &Markdown) -> Self
pub fn from_markdown(markdown: &Markdown) -> Self
Build LineMap from Markdown AST
Sourcepub fn get_entry(&self, line: usize) -> Option<&LineEntry>
pub fn get_entry(&self, line: usize) -> Option<&LineEntry>
Get the node index at a given visual line
Sourcepub fn get_node_at_line<'a>(
&self,
markdown: &'a Markdown,
line: usize,
) -> Option<&'a Node>
pub fn get_node_at_line<'a>( &self, markdown: &'a Markdown, line: usize, ) -> Option<&'a Node>
Get node at a given visual line
Sourcepub fn line_count(&self) -> usize
pub fn line_count(&self) -> usize
Total number of visual lines
Sourcepub fn invalidate_from(&mut self, from_line: usize)
pub fn invalidate_from(&mut self, from_line: usize)
Invalidate entries from a given line onwards (for incremental updates)
Sourcepub fn rebuild_from(&mut self, markdown: &Markdown, from_node_idx: usize)
pub fn rebuild_from(&mut self, markdown: &Markdown, from_node_idx: usize)
Rebuild from a specific line in the Markdown AST